@@ -61,10 +61,10 @@ static String* create_json(String* content, Project* project, Message* message,
     String* base_url_a = string_new();
     base_url_a = get_base_url(base_url_a);
     string_appendf(content, "{project:{name: \"%s\"}, ticket:{id: %d, url: \"%s/%s/ticket/%d\",fields:[",
-            project->name,
+            string_rawstr(project->name),
             message->id,
             string_rawstr(base_url_a),
-            g_project_code,
+            g_project_code_4_url,
             message->id);
     string_free(base_url_a);
     foreach (it, element_types) {
@@ -145,7 +145,7 @@ HOOK* exec_hook(HOOK* hook, Project* project, Message* message, List* elements,
         char hook_command[DEFAULT_LENGTH];
         char filename[DEFAULT_LENGTH];
         strcpy(filename, dp->d_name);
-        sprintf(hook_command, "%s/%s", hook_dir, filename);
+        sprintf(hook_command, "%s%s%s", hook_dir, PATH_SEPERATOR, filename);
         stat(hook_command, &fi);
         if (!S_ISDIR(fi.st_mode) &&                        /*ファイルで、 */
                 (fi.st_mode & S_IRUSR) &&                  /*所有者が読取可能で */
@@ -159,7 +159,7 @@ HOOK* exec_hook(HOOK* hook, Project* project, Message* message, List* elements,
             char dlpath[DEFAULT_LENGTH];
 
             result = list_new_element(hook->results);
-            sprintf(dlpath, "%s/%s", get_script_dir(script_dir), hook_command);
+            sprintf(dlpath, "%s%s%s", get_script_dir(script_dir), PATH_SEPERATOR, hook_command);
             handle = dlopen(dlpath, RTLD_LAZY);
             if (!handle) {
                 d("dlopen failed: %s\n", dlerror());
@@ -174,19 +174,15 @@ HOOK* exec_hook(HOOK* hook, Project* project, Message* message, List* elements,
                 } else {
                     String* base_url_a = string_new();
                     base_url_a = get_base_url(base_url_a);
-                    d("execute func\n");
                     ret = func(hook_message_a);
                     string_free(base_url_a);
                     if (ret == 0) {
-                        d("ok\n");
                         sprintf(result->message, _("executed hook process(%s)"), hook_command);
                     } else {
-                        d("ng\n");
                         sprintf(result->message, _("[error] error occured in hook process(%s). (return code: %d)"), hook_command, ret);
                     }
                 }
             }
-            d("dlclose\n");
             dlclose(handle);
             list_add(hook->results, result);
         } else if (!S_ISDIR(fi.st_mode) &&                 /*ファイルで、 */
@@ -196,12 +192,28 @@ HOOK* exec_hook(HOOK* hook, Project* project, Message* message, List* elements,
             int ret;
             char* val_a;
             HOOK_RESULT* result;
+            char tmp_filename[DEFAULT_LENGTH];
+            FILE* f;
+            sprintf(tmp_filename, "tmp%stmp.XXXXXX", PATH_SEPERATOR);
+            sprintf(tmp_filename, "%s", mktemp(tmp_filename));
+            f = fopen(tmp_filename, "w");
+            if (f == NULL) {
+                die("failed to open temporary file.");
+            }
+            d("content_a: %s\n", string_rawstr(content_a));
+            fprintf(f, "%s", string_rawstr(content_a));
+            fclose(f);
             result = list_new_element(hook->results);
             strcpy(result->command, hook_command);
             val_a = xalloc(sizeof(char) * string_len(content_a) + strlen("STARBUG1_CONTENT=") + 1);
             put_env_a("STARBUG1_CONTENT", string_rawstr(content_a), val_a);
+            /* 引数を追加 */
+            strcat(hook_command, " ");
+            strcat(hook_command, tmp_filename);
             ret = system(hook_command);
             xfree(val_a);
+            /* 一時ファイルを削除する */
+            remove(tmp_filename);
             if (ret == 0) {
                 sprintf(result->message, _("executed hook process(%s)"), hook_command);
             } else {
